isPayable property

bool get isPayable

Returns true if this function can be used to send Core to a smart contract that the contract will actually keep. Normally, all Core sent with a transaction will be used to pay for energy fees and the rest will be sent back. Here however, the Core (minus the fees) will be kept by the contract.

Implementation

bool get isPayable => mutability == StateMutability.payable;