privateKey property
Uint8List
get
privateKey
Returns a copy so callers cannot mutate the stored private key.
Implementation
Uint8List get privateKey => Uint8List.fromList(_privateKey);
Returns a copy so callers cannot mutate the stored private key.
Uint8List get privateKey => Uint8List.fromList(_privateKey);