IpfsGateway class

Resolves IPFS references through a configurable gateway.

template must be an HTTP(S) URL containing {cid}. The placeholder is replaced with the CID and any path present in an ipfs:// reference.

Constructors

IpfsGateway({String template = defaultIpfsGatewayTemplate, Client? client, int maxResponseBytes = 1024 * 1024})

Properties

hashCode int
The hash code for this object.
no setterinherited
maxResponseBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readJson(String reference) Future<Object?>
Loads a JSON document, rejecting oversized or non-successful responses.
resolve(String reference) Uri
Converts reference into a fetchable URI.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited