BlockNum.genesis constructor
const
BlockNum.genesis()
Use the state of the blockchain with the first block
Implementation
const BlockNum.genesis() : useAbsolute = false, blockNum = 0;
Use the state of the blockchain with the first block
const BlockNum.genesis() : useAbsolute = false, blockNum = 0;