EIP712 class

Constructors

EIP712()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeData(String primaryType, Map<String, dynamic> data, Map<String, dynamic> types) String
Encodes a Map<String, dynamic> by encoding and concatenating each of its members
encodeField(String name, String type, dynamic value, Map<String, dynamic> types) → dynamic
encodeType(String primaryType, Map<String, dynamic> types) String
Encodes the type of an Map<String,dynamic> by encoding a comma delimited list of its members
findTypeDependencies(String primaryType, Map<String, dynamic> types, List<String> results) List<String>
Finds all types within a type definition Map<String,dynamic>
getMessageForSign({required Map<String, dynamic> typedData, bool hash = true, bool include0x = true}) String
Get a signable message from the typed data, accepts typedData and hash and hash is used when you want the hashed result of the output (keccak hash which ethereum uses)
hashStruct(String primaryType, Map<String, dynamic> data, Map<String, dynamic> types) Uint8List
Hashes a Map<String, dynamic>
hashType(String primaryType, Map<String, dynamic> types) Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sanitizeData(Map<String, dynamic> typedData) Map<String, dynamic>
Removes properties from a message Map<String,dynamic> that are not defined per EIP-712
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited