energyPrice property
How much ether to spend on a single unit of energy. Can be null, in which case the rpc server will choose this value.
Implementation
final XCBAmount? energyPrice;
How much ether to spend on a single unit of energy. Can be null, in which case the rpc server will choose this value.
final XCBAmount? energyPrice;