TransactionInformation class

Constructors

TransactionInformation.fromMap(Map<String, dynamic> map)

Properties

blockHash String?
The hash of the block containing this transaction. If this transaction has not been mined yet and is thus in no block, it will be null
final
blockNumber BlockNum
BlockNum of the block containing this transaction, or BlockNum.pending when the transaction is not part of any block yet.
final
energy int
How many units of energy have been used in this transaction.
final
energyPrice XCBAmount
The amount of Core that was used to pay for one unit of energy.
final
from XCBAddress
The sender of this transaction.
final
hash String
A hash of this transaction, in hexadecimal representation.
final
hashCode int
The hash code for this object.
no setterinherited
input Uint8List
The data sent with this transaction.
final
nonce int
The nonce of this transaction. A nonce is incremented per sender and transaction to make sure the same transaction can't be sent more than once.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
The ECDSA full signature used to sign this transaction.
final
to XCBAddress?
Address of the receiver. null when its a contract creation transaction
final
transactionIndex int?
Integer of the transaction's index position in the block. null when it's pending.
getter/setter pair
value XCBAmount
The amount of Core sent with this transaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited