getLogs method
Returns all logs matched by the filter in options.
See also:
- events, which can be used to obtain a stream of log events
- https://github.com/ethereum/wiki/wiki/JSON-RPC#xcb_getlogs
Implementation
Future<List<FilterEvent>> getLogs(FilterOptions options) {
final filter = _EventFilter(options);
return _makeRPCCall<List<dynamic>>('xcb_getLogs', [
filter._createParamsObject(true),
]).then((logs) {
return logs.map(filter.parseChanges).toList();
});
}