Cip150MetadataContract class
Client for the CIP-150 on-chain key-value metadata interface.
- Inheritance
-
- Object
- GeneratedContract
- Cip150MetadataContract
- Available extensions
Constructors
- Cip150MetadataContract({required XCBAddress address, required Web3Client client, required int networkId})
Properties
- client → Web3Client
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- networkId → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- self → DeployedContract
-
finalinherited
Methods
-
checkSignature(
ContractFunction function, String expected) → bool -
Returns whether the
functionhas theexpectedselector.inherited -
count(
{BlockNum? atBlock}) → Future< BigInt> -
getByIndex(
BigInt index, {BlockNum? atBlock}) → Future< Cip150MetadataEntry> -
getValue(
String key, {BlockNum? atBlock}) → Future< String> -
hasKey(
String key, {BlockNum? atBlock}) → Future< bool> -
isSealed(
String key, {BlockNum? atBlock}) → Future< bool> -
listKeys(
{BlockNum? atBlock}) → Future< List< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
ContractFunction function, List params, BlockNum? atBlock) → Future< List> -
inherited
-
readAll(
{BlockNum? atBlock, bool includeSealedState = true}) → Future< List< Cip150MetadataEntry> > - Reads every entry, optionally including its sealed state.
-
readLabCertificate(
IpfsGateway gateway) → Future< Cip152LabCertificate?> -
Available on Cip150MetadataContract, provided by the Cip152MetadataContractExtension extension
Resolves and validates the current CIP-152 lab certificate. -
readLifecycle(
) → Future< Cip151Lifecycle> -
Available on Cip150MetadataContract, provided by the Cip151MetadataContractExtension extension
Reads CIP-151 lifecycle values that exist on this contract. -
sealKey(
String key, {required Credentials credentials, Transaction? transaction}) → Future< String> -
setValue(
String key, String value, {required Credentials credentials, Transaction? transaction}) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
-
write(
Credentials credentials, Transaction? base, ContractFunction function, List parameters) → Future< String> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited