Cip151Lifecycle class
Typed lifecycle metadata defined by CIP-151.
Constructors
- Cip151Lifecycle({DateTime? tokenExpiration, DateTime? tradingStop})
-
const
-
Cip151Lifecycle.fromMetadata(Map<
String, String> metadata) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenExpiration → DateTime?
-
final
- tradingStop → DateTime?
-
final
Methods
-
isExpiredAt(
DateTime time) → bool -
isTradingStoppedAt(
DateTime time) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited