isConstant property

bool get isConstant

Returns true if this function is constant, i.e. it cannot modify the state of the blockchain when called. This allows the function to be called without sending Core or energy as the connected client can compute it locally, no expensive mining will be required.

Implementation

bool get isConstant =>
    mutability == StateMutability.view || mutability == StateMutability.pure;