maxEnergy property
The maximum amount of energy to spend.
If maxEnergy is null, this library will ask the rpc node to estimate a
reasonable spending via Web3Client.estimateEnergy.
Energy that is not used but included in maxEnergy will be returned.
Implementation
final int? maxEnergy;