getEnergyPrice method

Future<XCBAmount> getEnergyPrice()

Returns the amount of Core typically needed to pay for one unit of energy.

Although not strictly defined, this value will typically be a sensible amount to use.

Implementation

Future<XCBAmount> getEnergyPrice() async {
  final data = await _makeRPCCall<String>('xcb_energyPrice');

  return XCBAmount.fromUnitAndValue(XCBUnit.ore, hexToInt(data));
}